@@ -1,4 +1,18 @@
-# $Id: Token.pm,v 1.3 2004/03/23 22:08:58 cosimo Exp $
+# Device::Gsm::Sms::Token - SMS PDU message parser token
+# Copyright (C) 2002-2006 Cosimo Streppone, cosimo@cpan.org
+#
+# This program is free software; you can redistribute it and/or modify
+# it only under the terms of Perl itself.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# Perl licensing terms for details.
+#
+# Commercial support is available. Write me if you are
+# interested in new features or software support.
+#
+# $Id: Token.pm,v 1.5 2006/04/20 20:07:19 cosimo Exp $
 
 package Sms::Token;
 
@@ -19,6 +33,11 @@ sub new {
 #	my $class = ref $proto || $proto;
 	$options->{'data'} ||= [];
 
+	# Cannot load a token without its name
+	if( ! defined $name || $name eq '' ) {
+		return undef;
+	}
+
 	# Create basic structure for a token
 	my %token = (
 		# Name of token, see ->name()
